@@ -262,8 +262,8 @@ class EvaluateFactor(object):
         total_plcy_count = df["policy_number"].count()
         pct_impacted = count/total_plcy_count
 
-        curr_prem = df2["curr_earned_premium"].sum()
-        prop_prem = df2["prop_earned_premium"].sum()
+        curr_prem = df["curr_earned_premium"].sum()
+        prop_prem = df["prop_earned_premium"].sum()
         pct_change_prem = (prop_prem - curr_prem)/curr_prem
 
         curr_ppm2 = df2["curr_price_per_mile"].mean()
@@ -274,7 +274,7 @@ class EvaluateFactor(object):
         prop_ppm = df["prop_price_per_mile"].mean()
         pct_change_ppm = (prop_ppm - curr_ppm)/curr_ppm
 
-        il = df2["il"].sum()
+        il = df["il"].sum()
         curr_lr = il/curr_prem
         prop_lr = il/prop_prem
 
@@ -284,10 +284,6 @@ class EvaluateFactor(object):
         print('{:,}'.format(count), end = '              ')
         print('{:.2f}%'.format(pct_impacted*100))
 
-        print('\nPremium Change:     {:,.0f}'.format(curr_prem), end = '         ')
-        print('{:,.0f}'.format(prop_prem), end = '          ')
-        print('{:.2f}%'.format(pct_change_prem*100))
-
         print('\nImpacted Avg PPM:   {:,.2f}'.format(curr_ppm2), end = '           ')
         print('{:,.2f}'.format(prop_ppm2), end = '              ')
         print('{:.2f}%'.format(pct_change_ppm2*100))
@@ -296,6 +292,10 @@ class EvaluateFactor(object):
         print('{:,.2f}'.format(prop_ppm), end = '              ')
         print('{:.2f}%'.format(pct_change_ppm*100))
 
+        print('\nTotal Prem Change:  {:,.0f}'.format(curr_prem), end = '       ')
+        print('{:,.0f}'.format(prop_prem), end = '          ')
+        print('{:.2f}%'.format(pct_change_prem*100))
+
         print('\nTotal Loss Ratio:   {:.2f}%'.format(curr_lr*100), end= '          ')
         print('{:,.2f}%'.format(prop_lr*100), end = '             ')
         print('{:.2f}%'.format((prop_lr-curr_lr)/curr_lr*100))
